@@ -18,12 +18,12 @@ def Flider():
         print('Continuing...')
     save_paths = ['flask_app/templates/', 'flask_app/config', 'flask_app/', 'flask_app/static/css/', 'flask_app/static/js/', '']
     file_names = ['index.html', 'mysqlcontroller.py', '__init__.py', 'style.css', 'scripts.js', 'server.py']
-    read_files = ['index', 'mysqlcontroller', '__init__', 'style', 'scripts', 'server']
+    read_names = ['index.flid', 'mysqlcontroller.flid', '__init__.flid', 'style.flid', 'scripts.flid', 'server.flid']
     for i in range(len(save_paths)):
         try:
             completeName = os.path.join(save_paths[i], file_names[i])
             write_file = open(completeName, 'w')
-            write_file.write(pkg_resources.read_text(read_files, read_files[i]))
+            write_file.write(pkg_resources.read_text(read_files, read_names[i]))
             write_file.close()
         except Exception as e:
             print(e)
